@@ -333,7 +333,7 @@ extern int my_master_node_id;
  * mode or there's no primary node, this macro returns
  * REAL_MASTER_NODE_ID.
  */
-#define PRIMARY_NODE_ID (Req_info->primary_node_id >=0 && VALID_BACKEND(Req_info->primary_node_id) ? \
+#define PRIMARY_NODE_ID (Req_info->primary_node_id >=0 && VALID_BACKEND_RAW(Req_info->primary_node_id) ? \
 						 Req_info->primary_node_id:REAL_MASTER_NODE_ID)
 #define IS_PRIMARY_NODE_ID(node_id)	(node_id == PRIMARY_NODE_ID)
 
@@ -742,5 +742,6 @@ extern int pool_frontend_exists(void);
 extern pid_t pool_waitpid(int *status);
 extern int write_status_file(void);
 extern void do_health_check_child(int *node_id);
+extern int get_next_master_node(void);
 
 #endif /* POOL_H */
