@@ -37,7 +37,7 @@ function install_pgpool
 
 	test -d $log || mkdir $log
         
-	make install -C $dir/../../ -e prefix=${PGPOOL_PATH} >& $log/regression.log 2>&1
+	make install HEALTHCHECK_DEBUG=1 -C $dir/../../ -e prefix=${PGPOOL_PATH} >& regression.log 2>&1
 
 	if [ $? != 0 ];then
 	    echo "make install failed"
@@ -47,9 +47,6 @@ function install_pgpool
 	echo "moving pgpool_setup to temporary installation path ..."
         cp $dir/../pgpool_setup ${PGPOOL_PATH}/pgpool_setup
 	export PGPOOL_SETUP=$PGPOOL_PATH/pgpool_setup
-	echo "moving watchdog_setup to temporary installation path ..."
-        cp $dir/../watchdog_setup ${PGPOOL_PATH}/watchdog_setup
-	export WATCHDOG_SETUP=$PGPOOL_PATH/watchdog_setup
 }
 
 function verify_pginstallation
@@ -75,7 +72,6 @@ function export_env_vars
 		# check if pgpool is in the path
 		PGPOOL_PATH=/usr/local
 		export PGPOOL_SETUP=$HOME/bin/pgpool_setup
-		export WATCHDOG_SETUP=$HOME/bin/watchdog_setup
  	fi
 	
 	if [[ -z "$PGBENCH_PATH" ]]; then
@@ -95,9 +91,9 @@ function export_env_vars
 
 	PGPOOLLIB=${PGPOOL_INSTALL_DIR}/lib
 	if [ -z "$LD_LIBRARY_PATH" ];then
-	    export LD_LIBRARY_PATH=${PGPOOLLIB}:${PGLIB}
+	    export LD_LIBRARY_PATH=$PGPOOLLIB
 	else
-	    export LD_LIBRARY_PATH=${PGPOOLLIB}:${PGLIB}:${LD_LIBRARY_PATH}
+	    export LD_LIBRARY_PATH=${PGPOOLLIB}:${LD_LIBRARY_PATH}
 	fi
 
 	export TESTLIBS=$dir/libs.sh
@@ -164,7 +160,6 @@ elif [ "$MODE" = "noinstall" ]; then
 		PGPOOL_PATH=$PGPOOL_INSTALL_PATH
 	fi
         export PGPOOL_SETUP=$dir/../pgpool_setup
-        export WATCHDOG_SETUP=$dir/../watchdog_setup
 else
 	echo $MODE : Invalid mode
 	exit -1
@@ -173,7 +168,6 @@ fi
 verify_pginstallation
 export_env_vars
 print_info
-source $TESTLIBS
 
 #Start executing tests
 rm -fr $log
@@ -191,7 +185,6 @@ for i in $dirs
 do
 	cd $i
 	echo -n "testing $i..."
-	clean_all
 	timeout $TIMEOUT ./test.sh > $log/$i 2>&1
 	rtn=$?
 	if [ $rtn = 0 ];then
