@@ -5,7 +5,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2021	PgPool Global Development Group
+ * Copyright (c) 2003-2016	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -90,20 +90,6 @@ void pool_ssl_negotiate_clientserver(POOL_CONNECTION *cp) {
 
 	switch (server_response) {
 		case 'S':
-
-			/*
-			 * At this point the server read buffer must be empty. Otherwise it
-			 * is possible that a man-in-the-middle attack is ongoing.
-			 * So we immediately close the communication channel.
-			 */
-			if (!pool_read_buffer_is_empty(cp))
-			{
-				ereport(FATAL,
-						(errcode(ERRCODE_PROTOCOL_VIOLATION),
-						 errmsg("received unencrypted data after SSL request"),
-						 errdetail("This could be an evidence of an attempted man-in-the-middle attacck.")));
-			}
-
 			SSL_set_fd(cp->ssl, cp->fd);
 			SSL_RETURN_VOID_IF( (SSL_connect(cp->ssl) < 0),
 			                    "SSL_connect");
@@ -138,19 +124,6 @@ void pool_ssl_negotiate_serverclient(POOL_CONNECTION *cp) {
 		/* write back an "SSL accept" response */
 		pool_write_and_flush(cp, "S", 1);
 
-		/*
-		 * At this point the frontend read buffer must be empty. Otherwise it
-		 * is possible that a man-in-the-middle attack is ongoing.
-		 * So we immediately close the communication channel.
-		 */
-		if (!pool_read_buffer_is_empty(cp))
-		{
-			ereport(FATAL,
-					(errcode(ERRCODE_PROTOCOL_VIOLATION),
-					 errmsg("received unencrypted data after SSL request"),
-					 errdetail("This could be either a client-software bug or evidence of an attempted man-in-the-middle attacck.")));
-		}
-
 		SSL_set_fd(cp->ssl, cp->fd);
 		SSL_RETURN_VOID_IF( (SSL_accept(cp->ssl) < 0), "SSL_accept");
 		cp->ssl_active = 1;
@@ -293,14 +266,6 @@ static int init_ssl_ctx(POOL_CONNECTION *cp, enum ssl_conn_type conntype) {
 	 */
 	SSL_CTX_set_mode(cp->ssl_ctx, SSL_MODE_ACCEPT_MOVING_WRITE_BUFFER);
 
-	/* set up the allowed cipher list */
-	error = SSL_CTX_set_cipher_list(cp->ssl_ctx, pool_config->ssl_ciphers);
-	SSL_RETURN_ERROR_IF((error != 1), "Setting allowed cipher list");
-
-	/* Let server choose order */
-	if (pool_config->ssl_prefer_server_ciphers)
-		SSL_CTX_set_options(cp->ssl_ctx, SSL_OP_CIPHER_SERVER_PREFERENCE);
-
 	if ( conntype == ssl_conn_serverclient) {
 		error = SSL_CTX_use_certificate_chain_file(cp->ssl_ctx,
 		                                     pool_config->ssl_cert);
@@ -385,7 +350,7 @@ void pool_ssl_close(POOL_CONNECTION *cp) { return; }
 int pool_ssl_read(POOL_CONNECTION *cp, void *buf, int size) {
 	ereport(WARNING,
 			(errmsg("pool_ssl: SSL i/o called but SSL support is not available")));
-	notice_backend_error(cp->db_node_id, true);
+	notice_backend_error(cp->db_node_id, REQ_DETAIL_SWITCHOVER);
 	child_exit(POOL_EXIT_AND_RESTART);
 	return -1; /* never reached */
 }
@@ -393,7 +358,7 @@ int pool_ssl_read(POOL_CONNECTION *cp, void *buf, int size) {
 int pool_ssl_write(POOL_CONNECTION *cp, const void *buf, int size) {
 	ereport(WARNING,
 			(errmsg("pool_ssl: SSL i/o called but SSL support is not available")));
-	notice_backend_error(cp->db_node_id, true);
+	notice_backend_error(cp->db_node_id, REQ_DETAIL_SWITCHOVER);
 	child_exit(POOL_EXIT_AND_RESTART);
 	return -1; /* never reached */
 }
